Module executor

Module executor 

Resolve the document to values

Structs

ExecutionError
Error type for errors that occur during query execution
Executor
Query execution engine
FieldError
Error type for errors that occur during field resolution
LookAheadArgument
Lazy-evaluated argument used in look-ahead operations on an executed GraphQL query.
LookAheadChildren
Children of a LookAheadSelection.
LookAheadList
Lazy-evaluated list used in look-ahead operations on an executed GraphQL query.
LookAheadObject
Lazy-evaluated input object used in look-ahead operations on an executed GraphQL query.
LookAheadSelection
Selection of an executed GraphQL query, used in look-ahead operations.
OwnedExecutor
Executor owning all its variables. Can be used after Executor was destroyed.
Registry
A type registry used to build schemas

Enums

Applies
Indication whether a field is available in all types of an interface or only in a certain subtype.
FieldPath
LookAheadValue
JSON-like value performing look-ahead operations on an executed GraphQL query.

Traits

Context
Marker trait for types that can act as context objects for GraphQL types.
FromContext
Conversion trait for context types
IntoFieldError
Custom error handling trait to enable error types other than FieldError to be specified as return value.

Functions

execute_validated_query
Create new Executor and start query/mutation execution. Returns IsSubscription error if subscription is passed.
execute_validated_query_async
Create new Executor and start asynchronous query execution. Returns IsSubscription error if subscription is passed.
resolve_validated_subscription
Initialize new Executor and start resolving subscription into stream asynchronously. Returns NotSubscription error if query or mutation is passed

Type Aliases

ExecutionResult
The result of resolving an unspecified field
FieldResult
The result of resolving the value of a field of type T
ValuesStream
Boxed Stream yielding Result<Value<S>, ExecutionError<S>>
Variables
The map of variables used for substitution during query execution