pub type Variables<S = DefaultScalarValue> = HashMap<String, InputValue<S>>;Expand description
The map of variables used for substitution during query execution
pub type Variables<S = DefaultScalarValue> = HashMap<String, InputValue<S>>;The map of variables used for substitution during query execution