LocalDate

Type Alias LocalDate 

pub type LocalDate = Date;
Available on crate feature jiff only.
Representation of a civil date in the Gregorian calendar.

Corresponds to a triple of year, month and day. Every value is guaranteed to be a valid Gregorian calendar date. For example, both 2023-02-29 and 2023-11-31 are invalid and cannot be represented.

LocalDate scalar compliant.

See also jiff::civil::Date for details.

Aliased Type

pub struct LocalDate { /* private fields */ }