IsInputType

Trait IsInputType 

pub trait IsInputType<S: ScalarValue>: GraphQLType<S> {
    // Provided method
    fn mark() { ... }
}
Marker trait for types which can be used as input types.

The GraphQL specification differentiates between input and output types. Each type which can be used as an input type should implement this trait. The specification defines enum, scalar, and input object input types.

Provided Methods

fn mark()

An arbitrary function without meaning.

May contain compile timed check logic which ensures that types are used correctly according to the GraphQL specification.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<S, T, const N: usize> IsInputType<S> for [T; N]
where T: IsInputType<S>, S: ScalarValue,

Source

impl<S, T> IsInputType<S> for &T
where T: IsInputType<S> + ?Sized, S: ScalarValue,

Source

impl<S, T> IsInputType<S> for Arc<T>
where T: IsInputType<S> + ?Sized, S: ScalarValue,

Source

impl<S, T> IsInputType<S> for Box<T>
where T: IsInputType<S> + ?Sized, S: ScalarValue,

Source

impl<S, T> IsInputType<S> for Option<T>
where T: IsInputType<S>, S: ScalarValue,

Source

impl<S, T> IsInputType<S> for Vec<T>
where T: IsInputType<S>, S: ScalarValue,

Source

impl<S, T> IsInputType<S> for [T]
where T: IsInputType<S>, S: ScalarValue,

Source

impl<S> IsInputType<S> for str
where S: ScalarValue,

Source

impl<Tz, __S> IsInputType<__S> for DateTime<Tz>

Available on crate feature chrono only.
Source

impl<__S> IsInputType<__S> for BigDecimal
where __S: ScalarValue,

Available on crate feature bigdecimal only.
Source

impl<__S> IsInputType<__S> for CompactString
where __S: ScalarValue,

Source

impl<__S> IsInputType<__S> for Date
where __S: ScalarValue,

Available on crate feature jiff only.
Source

impl<__S> IsInputType<__S> for Date
where __S: ScalarValue,

Available on crate feature time only.
Source

impl<__S> IsInputType<__S> for DateTime
where __S: ScalarValue,

Available on crate feature bson only.
Source

impl<__S> IsInputType<__S> for DateTime
where __S: ScalarValue,

Available on crate feature jiff only.
Source

impl<__S> IsInputType<__S> for Decimal
where __S: ScalarValue,

Available on crate feature rust_decimal only.
Source

impl<__S> IsInputType<__S> for NaiveDate
where __S: ScalarValue,

Available on crate feature chrono only.
Source

impl<__S> IsInputType<__S> for NaiveDateTime
where __S: ScalarValue,

Available on crate feature chrono only.
Source

impl<__S> IsInputType<__S> for NaiveTime
where __S: ScalarValue,

Available on crate feature chrono only.
Source

impl<__S> IsInputType<__S> for ObjectId
where __S: ScalarValue,

Available on crate feature bson only.
Source

impl<__S> IsInputType<__S> for Offset
where __S: ScalarValue,

Available on crate feature jiff only.
Source

impl<__S> IsInputType<__S> for OffsetDateTime
where __S: ScalarValue,

Available on crate feature time only.
Source

impl<__S> IsInputType<__S> for PrimitiveDateTime
where __S: ScalarValue,

Available on crate feature time only.
Source

impl<__S> IsInputType<__S> for Span
where __S: ScalarValue,

Available on crate feature jiff only.
Source

impl<__S> IsInputType<__S> for String
where __S: ScalarValue,

Source

impl<__S> IsInputType<__S> for Time
where __S: ScalarValue,

Available on crate feature jiff only.
Source

impl<__S> IsInputType<__S> for Time
where __S: ScalarValue,

Available on crate feature time only.
Source

impl<__S> IsInputType<__S> for TimeZone
where __S: ScalarValue,

Available on crate feature jiff only.
Source

impl<__S> IsInputType<__S> for Timestamp
where __S: ScalarValue,

Available on crate feature jiff only.
Source

impl<__S> IsInputType<__S> for Tz
where __S: ScalarValue,

Available on crate feature chrono-tz only.
Source

impl<__S> IsInputType<__S> for Url
where __S: ScalarValue,

Available on crate feature url only.
Source

impl<__S> IsInputType<__S> for UtcOffset
where __S: ScalarValue,

Available on crate feature time only.
Source

impl<__S> IsInputType<__S> for Uuid
where __S: ScalarValue,

Available on crate feature uuid only.
Source

impl<__S> IsInputType<__S> for Zoned
where __S: ScalarValue,

Available on crate feature jiff only.
Source

impl<__S> IsInputType<__S> for bool
where __S: ScalarValue,

Source

impl<__S> IsInputType<__S> for f64
where __S: ScalarValue,

Source

impl<__S> IsInputType<__S> for i32
where __S: ScalarValue,

Implementors

Source

impl<S, T> IsInputType<S> for Nullable<T>
where T: IsInputType<S>, S: ScalarValue,

Source

impl<__S> IsInputType<__S> for ArcStr
where __S: ScalarValue,

Source

impl<__S> IsInputType<__S> for Episode
where __S: ScalarValue,

Available on crate feature expose-test-schema only.
Source

impl<__S> IsInputType<__S> for ID
where __S: ScalarValue,

Source

impl<__S> IsInputType<__S> for juniper::integrations::jiff::TimeZone
where __S: ScalarValue,

Available on crate feature jiff only.
Source

impl<__S> IsInputType<__S> for TypeKind
where __S: ScalarValue,