Module parser

Module parser 

Query parser and language utilities

Structs

SourcePosition
A reference to a line and column in an input source file
Span
Range of characters in the input source, starting at the character pointed by the start field and ending just before the end marker.
Spanning
Data structure used to wrap items into a Span.

Enums

LexerError
Error when tokenizing the input source
ParseError
Error while parsing a GraphQL query
ScalarToken
A single scalar value literal
Token
A single token in the input source