Resolve the document to values
Structs
- Execution
Error - Error type for errors that occur during query execution
- Executor
- Query execution engine
- Field
Error - Error type for errors that occur during field resolution
- Look
Ahead Argument - Lazy-evaluated argument used in look-ahead operations on an executed GraphQL query.
- Look
Ahead Children - Children of a
LookAheadSelection. - Look
Ahead List - Lazy-evaluated list used in look-ahead operations on an executed GraphQL query.
- Look
Ahead Object - Lazy-evaluated input object used in look-ahead operations on an executed GraphQL query.
- Look
Ahead Selection - Selection of an executed GraphQL query, used in look-ahead operations.
- Owned
Executor Executorowning all its variables. Can be used afterExecutorwas destroyed.- Registry
- A type registry used to build schemas
Enums
- Applies
- Indication whether a field is available in all types of an interface or only in a certain subtype.
- Field
Path - Look
Ahead Value - JSON-like value performing look-ahead operations on an executed GraphQL query.
Traits
- Context
- Marker trait for types that can act as context objects for
GraphQLtypes. - From
Context - Conversion trait for context types
- Into
Field Error - Custom error handling trait to enable error types other than
FieldErrorto be specified as return value.
Functions
- execute_
validated_ query - Create new
Executorand start query/mutation execution. ReturnsIsSubscriptionerror if subscription is passed. - execute_
validated_ query_ async - Create new
Executorand start asynchronous query execution. ReturnsIsSubscriptionerror if subscription is passed. - resolve_
validated_ subscription - Initialize new
Executorand start resolving subscription into stream asynchronously. ReturnsNotSubscriptionerror if query or mutation is passed
Type Aliases
- Execution
Result - The result of resolving an unspecified field
- Field
Result - The result of resolving the value of a field of type
T - Values
Stream - Boxed
StreamyieldingResult<Value<S>, ExecutionError<S>> - Variables
- The map of variables used for substitution during query execution