pub trait IsInputType<S: ScalarValue>: GraphQLType<S> {
// Provided method
fn mark() { ... }
}Expand description
Marker trait for types which can be used as input types.
The GraphQL specification differentiates between input and output types. Each type which can be used as an input type should implement this trait. The specification defines enum, scalar, and input object input types.
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<S, T, const N: usize> IsInputType<S> for [T; N]where
T: IsInputType<S>,
S: ScalarValue,
impl<S, T, const N: usize> IsInputType<S> for [T; N]where
T: IsInputType<S>,
S: ScalarValue,
Sourceimpl<S, T> IsInputType<S> for &T
impl<S, T> IsInputType<S> for &T
Sourceimpl<S, T> IsInputType<S> for Arc<T>
impl<S, T> IsInputType<S> for Arc<T>
Sourceimpl<S, T> IsInputType<S> for Box<T>
impl<S, T> IsInputType<S> for Box<T>
Sourceimpl<S, T> IsInputType<S> for Option<T>where
T: IsInputType<S>,
S: ScalarValue,
impl<S, T> IsInputType<S> for Option<T>where
T: IsInputType<S>,
S: ScalarValue,
Sourceimpl<S, T> IsInputType<S> for Vec<T>where
T: IsInputType<S>,
S: ScalarValue,
impl<S, T> IsInputType<S> for Vec<T>where
T: IsInputType<S>,
S: ScalarValue,
Sourceimpl<S, T> IsInputType<S> for [T]where
T: IsInputType<S>,
S: ScalarValue,
impl<S, T> IsInputType<S> for [T]where
T: IsInputType<S>,
S: ScalarValue,
impl<S> IsInputType<S> for strwhere
S: ScalarValue,
impl<Tz, __S> IsInputType<__S> for DateTime<Tz>
Available on crate feature
chrono only.impl<__S> IsInputType<__S> for BigDecimalwhere
__S: ScalarValue,
Available on crate feature
bigdecimal only.impl<__S> IsInputType<__S> for CompactStringwhere
__S: ScalarValue,
impl<__S> IsInputType<__S> for Datewhere
__S: ScalarValue,
Available on crate feature
jiff only.impl<__S> IsInputType<__S> for Datewhere
__S: ScalarValue,
Available on crate feature
time only.impl<__S> IsInputType<__S> for DateTimewhere
__S: ScalarValue,
Available on crate feature
bson only.impl<__S> IsInputType<__S> for DateTimewhere
__S: ScalarValue,
Available on crate feature
jiff only.impl<__S> IsInputType<__S> for Decimalwhere
__S: ScalarValue,
Available on crate feature
rust_decimal only.impl<__S> IsInputType<__S> for NaiveDatewhere
__S: ScalarValue,
Available on crate feature
chrono only.impl<__S> IsInputType<__S> for NaiveDateTimewhere
__S: ScalarValue,
Available on crate feature
chrono only.impl<__S> IsInputType<__S> for NaiveTimewhere
__S: ScalarValue,
Available on crate feature
chrono only.impl<__S> IsInputType<__S> for ObjectIdwhere
__S: ScalarValue,
Available on crate feature
bson only.impl<__S> IsInputType<__S> for Offsetwhere
__S: ScalarValue,
Available on crate feature
jiff only.impl<__S> IsInputType<__S> for OffsetDateTimewhere
__S: ScalarValue,
Available on crate feature
time only.impl<__S> IsInputType<__S> for PrimitiveDateTimewhere
__S: ScalarValue,
Available on crate feature
time only.impl<__S> IsInputType<__S> for Spanwhere
__S: ScalarValue,
Available on crate feature
jiff only.impl<__S> IsInputType<__S> for Stringwhere
__S: ScalarValue,
impl<__S> IsInputType<__S> for Timewhere
__S: ScalarValue,
Available on crate feature
jiff only.impl<__S> IsInputType<__S> for Timewhere
__S: ScalarValue,
Available on crate feature
time only.impl<__S> IsInputType<__S> for TimeZonewhere
__S: ScalarValue,
Available on crate feature
jiff only.impl<__S> IsInputType<__S> for Timestampwhere
__S: ScalarValue,
Available on crate feature
jiff only.impl<__S> IsInputType<__S> for Tzwhere
__S: ScalarValue,
Available on crate feature
chrono-tz only.impl<__S> IsInputType<__S> for Urlwhere
__S: ScalarValue,
Available on crate feature
url only.impl<__S> IsInputType<__S> for UtcOffsetwhere
__S: ScalarValue,
Available on crate feature
time only.impl<__S> IsInputType<__S> for Uuidwhere
__S: ScalarValue,
Available on crate feature
uuid only.impl<__S> IsInputType<__S> for Zonedwhere
__S: ScalarValue,
Available on crate feature
jiff only.impl<__S> IsInputType<__S> for boolwhere
__S: ScalarValue,
impl<__S> IsInputType<__S> for f64where
__S: ScalarValue,
impl<__S> IsInputType<__S> for i32where
__S: ScalarValue,
Implementors
impl<S, T> IsInputType<S> for Nullable<T>where
T: IsInputType<S>,
S: ScalarValue,
impl<__S> IsInputType<__S> for ArcStrwhere
__S: ScalarValue,
impl<__S> IsInputType<__S> for Episodewhere
__S: ScalarValue,
Available on crate feature
expose-test-schema only.impl<__S> IsInputType<__S> for IDwhere
__S: ScalarValue,
impl<__S> IsInputType<__S> for juniper::integrations::jiff::TimeZonewhere
__S: ScalarValue,
Available on crate feature
jiff only.