[−][src]Struct juniper::Arguments
Field argument container
Methods
impl<'a, S> Arguments<'a, S> where
S: ScalarValue, [src]
S: ScalarValue,
pub fn get<T>(&self, key: &str) -> Option<T> where
T: FromInputValue<S>,
&'b S: ScalarRefValue<'b>, [src]
T: FromInputValue<S>,
&'b S: ScalarRefValue<'b>,
Get and convert an argument into the desired type.
If the argument is found, or a default argument has been provided,
the InputValue will be converted into the type T.
Returns Some if the argument is present and type conversion
succeeeds.